@@ -1,3 +1,24 @@
+seriesAccel <- function(x)
+{
+  diff(x, diff=2L, na.pad=TRUE) > 0
+}
+
+seriesDecel <- function(x)
+{
+  diff(x, diff=2L, na.pad=TRUE) < 0
+}
+
+seriesIncr <- function(x)
+{
+  diff(x, diff=1L, na.pad=TRUE) > 0
+}
+
+
+seriesDecr <- function(x)
+{
+  diff(x, diff=1L, na.pad=TRUE) < 0
+}
+
 `seriesHi` <-
 function(x) {
   UseMethod("seriesHi")
@@ -143,7 +164,7 @@ function(x)
 {
   if(has.Op(x))
     return(x[,grep('Open',colnames(x))])
-  NULL
+  stop('subscript out of bounds: no column name containing "Open"')
 }
 
 `has.Op` <-
@@ -160,7 +181,7 @@ function(x)
 {
   if(has.Hi(x))
     return(x[,grep('High',colnames(x))])
-  NULL
+  stop('subscript out of bounds: no column name containing "High"')
 }
 
 `has.Hi` <-
@@ -177,7 +198,7 @@ function(x)
 {
   if(has.Lo(x))
     return(x[,grep('Low',colnames(x))])
-  NULL
+  stop('subscript out of bounds: no column name containing "Low"')
 }
 
 `has.Lo` <-
@@ -194,7 +215,7 @@ function(x)
 {
   if(has.Cl(x))
     return(x[,grep('Close',colnames(x))])
-  NULL
+  stop('subscript out of bounds: no column name containing "Close"')
 }
 `has.Cl` <-
 function(x,which=FALSE)
@@ -212,7 +233,7 @@ function(x)
   #if(!identical(vo,integer(0)))
   if(has.Vo(x))
     return(x[,grep('Volume',colnames(x))])
-  NULL
+  stop('subscript out of bounds: no column name containing "Volume"')
 }
 `has.Vo` <-
 function(x,which=FALSE)
@@ -228,7 +249,7 @@ function(x)
 {
   if(has.Ad(x))
     return(x[,grep('Adjusted',colnames(x))])
-  NULL
+  stop('subscript out of bounds: no column name containing "Adjusted"')
 }
 `has.Ad` <-
 function(x,which=FALSE)
