@@ -14,672 +14,6 @@
 #
 #    CLV,CMD,OBV,KST,TDI,WHF,Aroon,ChAD,ChVol,WilliamsAD,
 #    Points, Stoch, SD, ...??? 
-`funToTA` <-
-function(x,drop.arg=1) {
-  drop.arg <- if(any(drop.arg < 1)) {
-    1:length(formals(x))
-  } else -drop.arg
-  fun.args <- paste(names(formals(x))[drop.arg],'=',sapply(formals(x), deparse)[drop.arg],sep='')
-  fun.args <- paste(gsub('=$','',fun.args),collapse=',')
-  paste('add',deparse(substitute(x)),'(',fun.args,') {',collapse='',sep='')
-}
-
-
-# addTA {{{
-`addTA` <-
-function(ta, order=NULL, on=NA, legend='auto', ...) {
-  if(is.character(ta)) {
-    if(exists(ta)) {
-      plot(do.call(paste('add',ta,sep=''),list(...)))
-    } else stop(paste('no TA method found for',paste('add',ta,sep='')))
-  } else {
-    lchob <- get.current.chob()
-    chobTA <- new("chobTA")
-    chobTA@new <- ifelse(is.na(on), TRUE, FALSE)
-    if(is.na(on)) {
-      chobTA@new <- TRUE
-    } else {
-      chobTA@new <- FALSE
-      chobTA@on  <- on
-    }
-    nrc <- NROW(lchob@xdata)
-  
-    ta <- try.xts(ta, error=FALSE)
-  
-    if(is.xts(ta)) {
-      x <- merge(lchob@xdata,convertIndex(ta, "POSIXct"))
-    } else {
-      if(NROW(ta) != nrc) stop('mismatched row lengths')
-      x <- merge(lchob@xdata, ta)
-    }
-    # for multicolumn TAs like MACD, get all new columns
-    chobTA@TA.values <- coredata(x)[lchob@xsubset,(NCOL(x)-NCOL(ta)+1):NCOL(x)]
-    chobTA@name <- "chartTA"
-    chobTA@call <- match.call()
-    chobTA@params <- list(xrange=lchob@xrange,
-                          colors=lchob@colors,
-                          spacing=lchob@spacing,
-                          width=lchob@width,
-                          bp=lchob@bp,
-                          x.labels=lchob@x.labels,
-                          order=order,legend=legend,
-                          pars=list(list(...)),
-                          time.scale=lchob@time.scale)
-   if(is.null(sys.call(-1))) {
-      TA <- lchob@passed.args$TA
-      lchob@passed.args$TA <- c(TA,chobTA)
-      lchob@windows <- lchob@windows + ifelse(chobTA@new,1,0)
-      do.call('chartSeries.chob',list(lchob))
-      #quantmod:::chartSeries.chob(lchob)
-      invisible(chobTA)
-    } else {
-     return(chobTA)
-    }
-  }
-}#}}}
-# chartTA {{{
-`chartTA` <-
-function(x) {
-    spacing <- x@params$spacing
-    width <- x@params$width
-
-    x.range <- x@params$xrange
-    x.range <- seq(x.range[1],x.range[2]*spacing)
-
-    tav <- x@TA.values
-
-    if(x@new) {
-      y.range <- seq(min(tav * 0.975, na.rm = TRUE), max(tav * 1.05, na.rm = TRUE),
-                     length.out=length(x.range))
-      plot(x.range,y.range,type='n',axes=FALSE,ann=FALSE)
-      coords <- par('usr')
-      rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-      grid(NA,NULL,col=x@params$colors$grid.col)
-    }
-
-    pars <- x@params$pars[[1]]
-    pars <- lapply(pars,
-             function(x) {
-              len <- NCOL(tav)
-              if(length(x) < len) {
-                rep(list(x), length.out=len)
-              } else rep(list(x),length.out=len)
-             })
-#    pars <- x@params$pars#[[1]]
-#    pars <- lapply(pars, function(x) rep(x, length.out=NCOL(tav)))
-
-    col.order <- if(is.null(x@params$order)) {
-      1:NCOL(tav)
-    } else x@params$order
-
-    if(is.null(x@params$legend)) legend <- function(...) {}
-    if(is.character(x@params$legend) && x@params$legend != "auto") {
-      legend("topleft", legend=x@params$legend, bty='n', y.inter=0.95)
-      legend <- function(...) { }
-    }
-
-    if(!x@new) {
-      legend <- function(legend,text.col) { list(legend=legend,text.col=text.col) }
-      formals(legend) <- formals(graphics::legend)
-    }
-
-    legend.text <- list()
-
-    # possibly able to handle newTA functionality
-    if(is.null(x@params$legend.name)) x@params$legend.name <- deparse(x@call[-1][[1]])
-
-    if(NCOL(tav) == 1) {
-      tmp.pars <- lapply(pars,function(x) x[[1]][[1]])
-      do.call('lines',c(list(seq(1,length(x.range),by=spacing)), list(tav), tmp.pars))
-      legend.text[[1]] <- legend('topleft',
-             legend=c(paste(x@params$legend.name,":"),sprintf("%.3f",last(na.omit(tav)))),
-             text.col=c(x@params$colors$fg.col,last(pars$col[[1]])),bty='n',y.inter=.95)
-    } else {
-      for(cols in col.order) {
-        tmp.pars <- lapply(pars,function(x) x[[cols]][[cols]])
-        do.call('lines',c(list(seq(1,length(x.range),by=spacing)), list(tav[,cols]), tmp.pars))
-        if(cols==1) { 
-          legend.text[[cols]] <- legend('topleft',
-                 legend=c(paste(x@params$legend.name,":")),
-                 text.col=c(x@params$colors$fg.col,last(pars$col[[cols]])),bty='n',y.inter=.95)
-        }
-        # for each column, add colname: value
-        Col.title <- colnames(tav)[cols]
-        legend.text[[cols]] <- legend('topleft',
-               legend=c(rep('',cols),paste(Col.title,":",
-                        sprintf("%.3f",last(na.omit(tav[,cols]))))),
-               text.col=pars$col[[cols]][cols],bty='n',y.inter=.95)
-      } 
-    }
-
-    axis(2)
-    box(col=x@params$colors$fg.col)
-    invisible(legend.text)
-} # }}}
-
-# setTA {{{
-`setTA` <-
-function(type=c('chartSeries','barChart','candleChart')) {
-  if('chartSeries' %in% type) setDefaults(chartSeries,TA=listTA())
-  if('barChart' %in% type) setDefaults(barChart,TA=listTA())
-  if('candleChart' %in% type) setDefaults(candleChart,TA=listTA())
-}# }}}
-# unsetTA {{{
-`unsetTA` <-
-function(type=c('chartSeries','barChart','candleChart')) {
-  if('chartSeries' %in% type) setDefaults(chartSeries,TA=NULL)
-  if('barChart' %in% type) setDefaults(barChart,TA=NULL)
-  if('candleChart' %in% type) setDefaults(candleChart,TA=NULL)
-}# }}}
-# listTA {{{
-`listTA` <-
-function(dev) {
-  if(missing(dev)) dev <- dev.cur()
-  sapply(get.chob()[[dev]]@passed.args$TA,function(x) x@call)
-} # }}}
-
-# addVo {{{
-`addVo` <- function() {
-   lchob <- get.current.chob() 
-  if(!lchob@show.vol) return()
- 
-  x <- as.matrix(lchob@xdata)
-  if(!has.Vo(x)) return()
-
-  Volumes <- Vo(x)
-  max.vol <- max(Volumes,na.rm=TRUE)
-  vol.scale <- list(100, "100s")
-  if (max.vol > 10000) 
-    vol.scale <- list(1000, "1000s")
-  if (max.vol > 1e+05) 
-    vol.scale <- list(10000, "10,000s")
-  if (max.vol > 1e+06) 
-    vol.scale <- list(1e+05, "100,000s")
-  if (max.vol > 1e+07) 
-    vol.scale <- list(1e+06, "millions")
-  
-  if(lchob@color.vol & is.OHLC(x)) {
-    # calculate colors for bars, if applicable.
-    Opens  <- Op(x)
-    Closes <- Cl(x)
-    if(lchob@multi.col) {
-      # colored bars - 4 color
-      last.Closes <- as.numeric(Lag(Closes))
-      last.Closes[1] <- Closes[1]
-      bar.col <- ifelse(Opens < Closes,
-                        ifelse(Opens > last.Closes,
-                               lchob@colors$dn.up.col,
-                               lchob@colors$up.up.col),
-                        ifelse(Opens < last.Closes,
-                               lchob@colors$dn.dn.col,
-                               lchob@colors$up.dn.col))
-    } else {
-      # colored bars - 2 color
-      bar.col <- ifelse(Opens < Closes,
-                        lchob@colors$up.col,
-                        lchob@colors$dn.col)
-    }
-      # 1 color bars
-  } else bar.col <- ifelse(!is.null(lchob@colors$Vo.bar.col),
-                           lchob@colors$Vo.bar.col,lchob@colors$border)
-  border.col <- ifelse(is.null(lchob@colors$border),
-                       bar.col,lchob@colors$border)
-
-  bar.col <- bar.col[lchob@xsubset]
-
-  chobTA <- new("chobTA")
-  chobTA@new <- TRUE
-
-  chobTA@TA.values <- (Volumes/vol.scale[[1]])[lchob@xsubset]
-  chobTA@name <- "chartVo"
-  chobTA@call <- match.call()
-  
-  chobTA@params <- list(xrange=lchob@xrange,
-                        colors=lchob@colors,
-                        color.vol=lchob@color.vol,
-                        multi.col=lchob@multi.col,
-                        spacing=lchob@spacing,
-                        width=lchob@width,
-                        bp=lchob@bp,
-                        vol.scale=vol.scale,
-                        x.labels=lchob@x.labels,
-                        bar.col=bar.col,border.col=border.col,
-                        time.scale=lchob@time.scale)
-
-  chobTA@params$thin <- ifelse(lchob@type %in% c('bars','matchsticks'),TRUE,FALSE)
-
-  if(is.null(sys.call(-1))) {
-    TA <- lchob@passed.args$TA
-    lchob@passed.args$TA <- c(TA,chobTA)
-    lchob@windows <- lchob@windows + ifelse(chobTA@new,1,0)
-    do.call('chartSeries.chob',list(lchob))
-    invisible(chobTA)
-  } else {
-   return(chobTA)
-  } 
-} # }}}
-# chartVo {{{
-`chartVo` <-
-function(x) {
-  # if volume is to be plotted, do so here
-    # scale volume - vol.divisor
-    if(class(x) != "chobTA") stop("chartVo requires a suitable chobTA object")
-    Volumes <- x@TA.values
-
-    spacing <- x@params$spacing
-    width <- x@params$width
-
-    x.range <- x@params$xrange
-    x.range <- seq(x.range[1],x.range[2]*spacing)
-
-#    multi.col <- x@params$multi.col
-    color.vol <- x@params$color.vol
-
-    vol.scale <- x@params$vol.scale
-    plot(x.range,seq(min(Volumes),max(Volumes),
-         length.out=length(x.range)),
-         type='n',axes=FALSE,ann=FALSE)
-    coords <- par('usr')
-    rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-    grid(NA,NULL,col=x@params$colors$grid.col)
-    x.pos <- 1 + spacing * (1:length(Volumes) - 1)
-
-    bar.col <- if(x@params$color.vol) {
-                 x@params$bar.col
-               } else x@params$border.col
-
-    border.col <- x@params$border.col
-
-    if(x@params$thin) {
-      # plot thin volume bars if appropriate
-      segments(x.pos,0,x.pos,Volumes,col=bar.col)
-    } else {
-      rect(x.pos-spacing/3,0,x.pos+spacing/3,Volumes,
-           col=bar.col,border=border.col)
-    }
-    legend("topleft",
-           legend=c("Volume:",format(last(Volumes)*vol.scale[[1]],big.mark=',')),
-           text.col=c(x@params$colors$fg.col, last(bar.col)), bty="n", y.inter=0.95)
-#   text(0, max(Volumes,na.rm=TRUE) * .9, "Volume:",pos=4)
-
-#   text(0, max(Volumes,na.rm=TRUE) * .9,
-#        paste("\n\n\n",format(last(Volumes)*vol.scale[[1]],big.mark=','), sep = ""), 
-#        pos = 4,col=last(bar.col))
-
-    axis(2)
-    box(col=x@params$colors$fg.col)
-} # }}}
-
-# addSMI {{{
-`addSMI` <- function(n=13,slow=25,fast=2,signal=9,ma.type='EMA') {
-
-  stopifnot("package:TTR" %in% search() || require("TTR",quietly=TRUE))
-
-  lchob <- get.current.chob()
-  
-  x <- as.matrix(lchob@xdata)
-
-  chobTA <- new("chobTA")
-  chobTA@new <- TRUE
-
-  xx <- if(is.OHLC(x)) {
-    cbind(Hi(x),Lo(x),Cl(x))
-  } else if(is.null(dim(x))) {
-    x
-  } else {
-    x[,1] 
-  }
-
-  smi <- SMI(xx, n=n, nFast=fast,
-             nSlow=slow, nSig=signal, maType=ma.type)
-
-# subset here
-# smi <- smi[lchob@sindex]
-
-  chobTA@TA.values <- smi[lchob@xsubset,]
-  chobTA@name <- "chartSMI"
-  chobTA@call <- match.call()
-  chobTA@params <- list(xrange=lchob@xrange,
-                        colors=lchob@colors,
-                        color.vol=lchob@color.vol,
-                        multi.col=lchob@multi.col,
-                        spacing=lchob@spacing,
-                        width=lchob@width,
-                        bp=lchob@bp,
-                        x.labels=lchob@x.labels,
-                        time.scale=lchob@time.scale,
-                        n=n,slow=slow,fast=fast,signal=signal,
-                        ma.type=ma.type)
-  if(is.null(sys.call(-1))) {
-    TA <- lchob@passed.args$TA
-    lchob@passed.args$TA <- c(TA,chobTA)
-    lchob@windows <- lchob@windows + ifelse(chobTA@new,1,0)
-    do.call('chartSeries.chob',list(lchob))
-    invisible(chobTA)
-  } else {
-   return(chobTA)
-  } 
-} #}}}
-# chartSMI {{{
-`chartSMI` <-
-function(x) {
-    spacing <- x@params$spacing
-    width <- x@params$width
-
-    x.range <- x@params$xrange
-    x.range <- seq(x.range[1],x.range[2]*spacing)
-
-    multi.col <- x@params$multi.col
-    color.vol <- x@params$color.vol
-
-# subset thinking ...
-#
-# could subset the TA.values here (or in addSMI more likely)
-# this way the calculation is performed on the entire set, but
-# the smaller view is printed.
-# 
-#   smi <- x@TA.values[x@sindex] ???
-#
-    smi <- x@TA.values
-
-    y.range <- seq(-max(abs(smi[,1]), na.rm = TRUE), max(abs(smi[,1]), 
-                   na.rm = TRUE), length.out = length(x.range)) * 1.05
-
-    plot(x.range,y.range,type='n',axes=FALSE,ann=FALSE)
-
-    coords <- par('usr')
-    rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-    grid(NA,NULL,col=x@params$colors$grid.col)
-
-    COLOR <- "#0033CC"
-    SIGNAL <- "#BFCFFF"
-
-    lines(seq(1,length(x.range),by=spacing),
-          smi[,1],col=COLOR,lwd=1,type='l')
-    lines(seq(1,length(x.range),by=spacing),
-          smi[,2],col=SIGNAL,lwd=1,lty='dotted',type='l')
-
-    text(0, last(y.range) * .9,
-         paste("Stochastic Momentum Index (",
-         paste(x@params$n,x@params$fast,x@params$slow,x@params$signal,sep=','),
-         "):", sep = ""), 
-         pos = 4)
-
-    text(0, last(y.range)*.9,
-        paste("\n\n\nSMI: ",sprintf("%.3f",last(smi[,1])), sep = ""), col = COLOR, 
-        pos = 4)
-
-    text(0, last(y.range)*.9,
-        paste("\n\n\n\n\nSignal: ",
-              sprintf("%.3f",last(smi[,2])), sep = ""), col = SIGNAL, 
-        pos = 4)
-
-    axis(2)
-    box(col=x@params$colors$fg.col)
-} # }}}
-
-# addWPR {{{
-`addWPR` <- function(n=14) {
-
-  stopifnot("package:TTR" %in% search() || require("TTR",quietly=TRUE))
-
-  lchob <- get.current.chob()
-
-  x <- as.matrix(lchob@xdata)
-
-  chobTA <- new("chobTA")
-  chobTA@new <- TRUE
-
-  xx <- if(is.OHLC(x)) {
-    cbind(Hi(x),Lo(x),Cl(x))
-  } else if(is.null(dim(x))) {
-    x
-  } else {
-    x[,1] 
-  }
-
-
-  wpr <- WPR(xx,n=n)
-
-  chobTA@TA.values <- as.numeric(wpr)[lchob@xsubset]
-  chobTA@name <- "chartWPR"
-  chobTA@call <- match.call()
-  chobTA@params <- list(xrange=lchob@xrange,
-                        colors=lchob@colors,
-                        color.vol=lchob@color.vol,
-                        multi.col=lchob@multi.col,
-                        spacing=lchob@spacing,
-                        width=lchob@width,
-                        bp=lchob@bp,
-                        x.labels=lchob@x.labels,
-                        time.scale=lchob@time.scale,
-                        n=n)
-  if(is.null(sys.call(-1))) {
-    TA <- lchob@passed.args$TA
-    lchob@passed.args$TA <- c(TA,chobTA)
-    lchob@windows <- lchob@windows + ifelse(chobTA@new,1,0)
-    do.call('chartSeries.chob',list(lchob))
-    invisible(chobTA)
-  } else {
-   return(chobTA)
-  } 
-} #}}}
-# chartWPR {{{
-`chartWPR` <-
-function(x) {
-    spacing <- x@params$spacing
-    width <- x@params$width
-
-    x.range <- x@params$xrange
-    x.range <- seq(x.range[1],x.range[2]*spacing)
-
-    multi.col <- x@params$multi.col
-    color.vol <- x@params$color.vol
-
-    n <- x@params$n
-    wpr <- x@TA.values
-
-    y.range <- seq(-0.1, max(abs(wpr), 
-                   na.rm = TRUE), length.out = length(x.range)) * 1.05
-
-    # create appropriately scaled empty plot area
-    plot(x.range,y.range,type='n',axes=FALSE,ann=FALSE)
-
-    coords <- par('usr')
-    rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-    grid(NA,NULL,col=x@params$colors$grid.col)
-
-    COLOR <- "#0033CC"
-
-    lines(seq(1,length(x.range),by=spacing),wpr,col=COLOR,lwd=1,type='l')
-
-    text(0, last(y.range)*.9,
-         paste("Williams %R (", x@params$n,"):", sep = ""), 
-        pos = 4)
-
-    text(0, last(y.range)*.9,
-        paste("\n\n\n",sprintf("%.3f",last(wpr)), sep = ""), col = COLOR, 
-        pos = 4)
-
-    axis(2)
-    box(col=x@params$colors$fg.col)
-} # }}}
-
-# addCMF {{{
-`addCMF` <- function(n=20) {
-
-  stopifnot("package:TTR" %in% search() || require("TTR",quietly=TRUE))
-
-  lchob <- get.current.chob()
-
-  x <- as.matrix(lchob@xdata)
-
-  chobTA <- new("chobTA")
-  chobTA@new <- TRUE
-
-  xx <- if(is.OHLC(x)) {
-    cbind(Hi(x),Lo(x),Cl(x))
-  } else stop("CMF only applicaple to HLC series")
-
-  cmf <- CMF(xx,Vo(x),n=n)
-
-  chobTA@TA.values <- cmf[lchob@xsubset]
-  chobTA@name <- "chartCMF"
-  chobTA@call <- match.call()
-  chobTA@params <- list(xrange=lchob@xrange,
-                        colors=lchob@colors,
-                        color.vol=lchob@color.vol,
-                        multi.col=lchob@multi.col,
-                        spacing=lchob@spacing,
-                        width=lchob@width,
-                        bp=lchob@bp,
-                        x.labels=lchob@x.labels,
-                        time.scale=lchob@time.scale,
-                        n=n)
-  if(is.null(sys.call(-1))) {
-    TA <- lchob@passed.args$TA
-    lchob@passed.args$TA <- c(TA,chobTA)
-    lchob@windows <- lchob@windows + ifelse(chobTA@new,1,0)
-    do.call('chartSeries.chob',list(lchob))
-    invisible(chobTA)
-  } else {
-   return(chobTA)
-  } 
-} #}}}
-# chartCMF {{{
-`chartCMF` <-
-function(x) {
-    spacing <- x@params$spacing
-    width <- x@params$width
-
-    x.range <- x@params$xrange
-    x.range <- seq(x.range[1],x.range[2]*spacing)
-
-    multi.col <- x@params$multi.col
-    color.vol <- x@params$color.vol
-
-    n <- x@params$n
-    cmf <- x@TA.values
-
-    y.range <- seq(-max(abs(cmf), na.rm = TRUE), max(abs(cmf), 
-                   na.rm = TRUE), length.out = length(x.range)) * 1.05
-
-    plot(x.range,y.range,
-         type='n',axes=FALSE,ann=FALSE)
-    coords <- par('usr')
-    rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-    grid(NA,NULL,col=x@params$colors$grid.col)
-
-    xx <- seq(1,length(x.range),by=spacing)
-    cmf.positive <- ifelse(cmf >= 0,cmf,0)
-    cmf.negative <- ifelse(cmf <  0,cmf,0)
-
-    polygon(c(xx,rev(xx)),c(cmf.positive,rep(0,length(cmf))),col=x@params$colors$up.col)
-    polygon(c(xx,rev(xx)),c(cmf.negative,rep(0,length(cmf))),col=x@params$colors$dn.col)
-
-    abline(h=0,col="#999999")
-
-    text(0, last(y.range)*.9,
-         paste("Chaikin Money Flow (", x@params$n,"):", sep = ""), 
-        pos = 4)
-
-    text(0, last(y.range)*.9,
-        paste("\n\n\n",sprintf("%.3f",last(cmf)), sep = ""), 
-        col = ifelse(last(cmf) > 0,x@params$colors$up.col,x@params$colors$dn.col), 
-        pos = 4)
-
-    axis(2)
-    box(col=x@params$colors$fg.col)
-} # }}}
-
-# addCMO {{{
-`addCMO` <- function(n=14) {
-
-  stopifnot("package:TTR" %in% search() || require("TTR",quietly=TRUE))
-
-  lchob <- get.current.chob()
-
-  x <- as.matrix(lchob@xdata)
-
-  chobTA <- new("chobTA")
-  chobTA@new <- TRUE
-
-  #  needs to accept any arguments for x, not just close
-
-  xx <- if(has.Cl(x)) {
-    Cl(x)
-  } else if(is.null(dim(x))) {
-    x
-  } else {
-    x[,1] 
-  }
-
-  cmo <- CMO(xx,n=n)
-
-  chobTA@TA.values <- cmo[lchob@xsubset]
-  chobTA@name <- "chartCMO"
-  chobTA@call <- match.call()
-  chobTA@params <- list(xrange=lchob@xrange,
-                        colors=lchob@colors,
-                        color.vol=lchob@color.vol,
-                        multi.col=lchob@multi.col,
-                        spacing=lchob@spacing,
-                        width=lchob@width,
-                        bp=lchob@bp,
-                        x.labels=lchob@x.labels,
-                        time.scale=lchob@time.scale,
-                        n=n)
-  if(is.null(sys.call(-1))) {
-    TA <- lchob@passed.args$TA
-    lchob@passed.args$TA <- c(TA,chobTA)
-    lchob@windows <- lchob@windows + ifelse(chobTA@new,1,0)
-    do.call('chartSeries.chob',list(lchob))
-    invisible(chobTA)
-  } else {
-   return(chobTA)
-  } 
-} #}}}
-# chartCMO {{{
-`chartCMO` <-
-function(x) {
-    spacing <- x@params$spacing
-    width <- x@params$width
-
-    x.range <- x@params$xrange
-    x.range <- seq(x.range[1],x.range[2]*spacing)
-
-    multi.col <- x@params$multi.col
-    color.vol <- x@params$color.vol
-
-    n <- x@params$n
-    cmo <- x@TA.values
-
-    y.range <- seq(-max(abs(cmo), na.rm = TRUE), max(abs(cmo), 
-                   na.rm = TRUE), length.out = length(x.range)) * 1.05
-
-    plot(x.range,y.range,
-         type='n',axes=FALSE,ann=FALSE)
-    coords <- par('usr')
-    rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-    grid(NA,NULL,col=x@params$colors$grid.col)
-
-    COLOR="#0033CC"
-
-    abline(h=0,col="#666666",lwd=1,lty='dotted')
-    lines(seq(1,length(x.range),by=spacing),cmo,col=COLOR,lwd=1,type='l')
-
-    text(0, last(y.range)*.9,
-         paste("Chande Momentum Oscillator (", x@params$n,"):", sep = ""), 
-        pos = 4)
-
-    text(0, last(y.range)*.9,
-        paste("\n\n\n",sprintf("%.3f",last(cmo)), sep = ""), col = COLOR, 
-        pos = 4)
-
-    axis(2)
-    box(col=x@params$colors$fg.col)
-} # }}}
-
 # addMomentum {{{
 `addMomentum` <- function(n=1) {
 
@@ -1137,12 +471,13 @@ function(x) {
     y.range <- seq(-max(abs(dpo), na.rm = TRUE), max(abs(dpo), 
                    na.rm = TRUE), length.out = length(x.range)) * 1.05
 
-    plot(x.range,y.range,
-         type='n',axes=FALSE,ann=FALSE)
-    coords <- par('usr')
-    rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-    grid(NA,NULL,col=x@params$colors$grid.col)
-
+    if(x@new) {
+      plot(x.range,y.range,
+           type='n',axes=FALSE,ann=FALSE)
+      coords <- par('usr')
+      rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
+      grid(NA,NULL,col=x@params$colors$grid.col)
+    }
     xx <- seq(1,length(x.range),by=spacing)
 
     dpo.tmp <- dpo
@@ -1240,12 +575,13 @@ function(x) {
     y.range <- seq(min(rsi,na.rm=TRUE)*.975,max(rsi,na.rm=TRUE)*1.05,
                    length.out=length(x.range))
 
-    plot(x.range,y.range,type='n',axes=FALSE,ann=FALSE)
-
-    coords <- par('usr')
-    rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-    grid(NA,NULL,col=x@params$colors$grid.col)
-
+    if(x@new) {
+      plot(x.range,y.range,type='n',axes=FALSE,ann=FALSE)
+  
+      coords <- par('usr')
+      rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
+      grid(NA,NULL,col=x@params$colors$grid.col)
+    }
     lines(seq(1,length(x.range),by=spacing),rsi,col='#0033CC',lwd=2,type='l')
     lines(seq(1,length(x.range),by=spacing),rsi,col='#BFCFFF',lwd=1,lty='dotted',type='l')
 
@@ -1317,9 +653,11 @@ function(x) {
 
     #param <- x@params$param; ma.type <- x@params$ma.type
     roc <- x@TA.values
-    plot(x.range,seq(min(roc*.975,na.rm=TRUE),max(roc*1.05,na.rm=TRUE),length.out=length(x.range)),
+    if(x@new) {
+      plot(x.range,seq(min(roc*.975,na.rm=TRUE),max(roc*1.05,na.rm=TRUE),length.out=length(x.range)),
          type='n',axes=FALSE,ann=FALSE)
-    grid(NA,NULL,col=x@params$colors$grid.col)
+      grid(NA,NULL,col=x@params$colors$grid.col)
+    }
     lines(seq(1,length(x.range),by=spacing),roc,col=x@params$col,lwd=2,type='l')
     #title(ylab=paste('RSI(',paste(c(n.up,collapse=','),')',sep=''))
     axis(2)
@@ -1677,11 +1015,13 @@ function(x) {
     y.range <- seq(-max(abs(macd),na.rm=TRUE),max(abs(macd),na.rm=TRUE),
                    length.out=length(x.range)) * 1.05
 
-    plot(x.range,y.range,type='n',axes=FALSE,ann=FALSE)
+    if(x@new) {
+      plot(x.range,y.range,type='n',axes=FALSE,ann=FALSE)
 
-    coords <- par('usr')
-    rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
-    grid(NA,NULL,col=x@params$colors$grid.col)
+      coords <- par('usr')
+      rect(coords[1],coords[3],coords[2],coords[4],col=x@params$colors$area)
+      grid(NA,NULL,col=x@params$colors$grid.col)
+    }
 
     if(x@params$histo) {
       x.pos <- 1 + spacing * (1:NROW(macd) -1)
@@ -1882,6 +1222,13 @@ function(x) {
 
   if(missing(bg)) bg <- col
 
+    xsubset <- x %in% lchob@xsubset
+    if(NROW(x) != NROW(y)) stop('x and y must be of equal lengths')
+    x <- x[xsubset]
+    if(!is.null(y))
+      y <- y[xsubset]
+
+
   chobTA@params <- list(xrange=lchob@xrange,
                         colors=lchob@colors,
                         color.vol=lchob@color.vol,
@@ -1932,7 +1279,7 @@ function(x) {
         Hi(xdata)
       } else Lo(xdata)
     } else xdata
- 
+
     if(is.null(y.points)) y.points <- y.data[x.points] * offset
 
     points(x=(x.points-1) * spacing + 1, y=y.points,
